@@ -3105,9 +3105,10 @@ main_terminal_program (int argc, char *argv [], char **environ)
 	
 	cb_options[0].descrip = (char *)cmdline_config;
 
-	/* pre-scan for -x and --execute options */
+	/* pre-scan for -x -e --command and --execute options */
 	for (i=1;i<argc;i++) {
-		if (!strcmp (argv [i], "-x") || !(strcmp (argv [i], "--execute"))) {
+		if (!strcmp (argv [i], "-x") || !strcmp (argv [i], "--execute") 
+			|| !strcmp (argv [i], "-e") || !strcmp (argv [i], "--command")) {
 			int last = i;
 			i++;
 			if (i == argc) {
