@@ -953,6 +953,12 @@ gnome_panel_applet_corba_init(AppletWidget *applet, const char *goad_id)
 						       &applet_servant->winid,
 						       &ev);
 	pg_return_val_if_fail(&ev, ev._major == CORBA_NO_EXCEPTION, NULL);
+	/* evil evil evil evil */
+	if (applet_servant->pspot == CORBA_OBJECT_NIL) {
+		g_free (applet_servant->goad_id);
+		g_free (applet_servant);
+		return NULL;
+	}
 
 	if(privcfg && *privcfg)
 		applet->privcfgpath = g_strdup(privcfg);
