@@ -386,7 +386,7 @@ setup_merge_directory(void)
 {
 	int len;
 
-	merge_main_dir = gnome_datadir_file("gnome/apps/");
+	merge_main_dir = gnome_datadir_file("gnome/apps");
 	merge_main_dir_len = merge_main_dir != NULL ? strlen (merge_main_dir) : 0;
 	merge_merge_dir = conditional_get_string ("/panel/Merge/Directory",
 						  "/etc/X11/applnk/",
@@ -418,8 +418,9 @@ setup_visuals (void)
 static void
 kill_free_drawers (void)
 {
-	GSList *li;
-	for (li = panel_list; li != NULL; li = li->next) {
+	GSList *li, *list;
+	list = g_slist_copy (panel_list); 
+	for (li = list; li != NULL; li = li->next) {
 		PanelData *pd = li->data;
 		if (IS_DRAWER_WIDGET (pd->panel) &&
 		    PANEL_WIDGET (BASEP_WIDGET (pd->panel)->panel)->master_widget == NULL) {
@@ -427,6 +428,7 @@ kill_free_drawers (void)
 			gtk_widget_destroy (pd->panel);
 		}
 	}
+	g_slist_free(list);
 }
 
 /* gets a GdkPixmap for a given X atom name whose value is an X Pixmap */
@@ -589,6 +591,8 @@ main(int argc, char **argv)
 	panel_tooltips = gtk_tooltips_new ();
 
 	xstuff_init ();
+	status_applet_create_offscreen ();
+
 	multiscreen_init ();
 
 	gnome_win_hints_init ();
@@ -606,8 +610,6 @@ main(int argc, char **argv)
 	if ( ! commie_mode)
 		write_global_config ();
 
-	gwmh_init ();
-
 	init_fr_chunks ();
 	
 	init_menus ();
@@ -642,8 +644,6 @@ main(int argc, char **argv)
 
 	panel_in_startup = FALSE;
 	
-	status_applet_create_offscreen ();
-
 	/*load these as the last thing to prevent some races any races from
 	  starting multiple goad_id's at once are libgnorba's problem*/
 	load_queued_externs ();
