@@ -37,7 +37,7 @@ tasklist_icon_check_mini (GwmhTask *task,  GtkWidget *widget)
 	GdkImage *image;
 	GdkPixmap *pixmap;
 	GdkBitmap *mask;
-	GdkPixbuf *pixbuf;
+	GdkPixbuf *pixbuf, *pixbuf2;
 	gint size;
 	static gulong KWM_WIN_ICON = 0;
 	Display *xdisplay;
@@ -102,8 +102,10 @@ tasklist_icon_check_mini (GwmhTask *task,  GtkWidget *widget)
 		
 		image = gdk_image_get (mask, 0, 0, width, height);
 		g_return_val_if_fail (image != NULL, FALSE);
-		
+	
+		pixbuf2 = pixbuf;
 		pixbuf = gdk_pixbuf_add_alpha (pixbuf, FALSE, 0, 0, 0);
+		gdk_pixbuf_unref(pixbuf2);
 		
 		data = gdk_pixbuf_get_pixels (pixbuf);
 		for (y = 0; y < gdk_pixbuf_get_height (pixbuf); y++) 
@@ -112,8 +114,8 @@ tasklist_icon_check_mini (GwmhTask *task,  GtkWidget *widget)
 				data += 3;
 				*data++ = gdk_image_get_pixel (image, x, y) == 0 ? 0 : 255;
 			}
-		
 		gdk_pixmap_unref (mask);
+		gdk_image_destroy(image);	
 	}
 
 	gdk_flush ();
@@ -187,7 +189,9 @@ tasklist_icon_check_x (GwmhTask *task,  GtkWidget *widget)
 	gdk_gc_destroy (gc);
 
 	if (depth == 1) {
+		scaled = pixbuf;
 		pixbuf = gdk_pixbuf_add_alpha (pixbuf, FALSE, 0, 0, 0);
+		gdk_pixbuf_unref(scaled);
 	}
 	
 	if (wmhints->flags & IconMaskHint) {
@@ -201,7 +205,7 @@ tasklist_icon_check_x (GwmhTask *task,  GtkWidget *widget)
 
 	       image = gdk_image_get (mask, 0, 0, width, height);
 	       g_return_val_if_fail (image != NULL, FALSE);
-
+	       
 	       scaled = pixbuf;
 	       pixbuf = gdk_pixbuf_add_alpha (pixbuf, FALSE, 0, 0, 0);
 	       gdk_pixbuf_unref (scaled);
